# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: validator_change.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import events_pb2 as events__pb2
from . import ledger_info_pb2 as ledger__info__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='validator_change.proto',
  package='types',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x16validator_change.proto\x12\x05types\x1a\x0c\x65vents.proto\x1a\x11ledger_info.proto\"\x90\x01\n\x1dValidatorChangeEventWithProof\x12>\n\x15ledger_info_with_sigs\x18\x01 \x01(\x0b\x32\x1f.types.LedgerInfoWithSignatures\x12/\n\x10\x65vent_with_proof\x18\x02 \x01(\x0b\x32\x15.types.EventWithProofb\x06proto3')
  ,
  dependencies=[events__pb2.DESCRIPTOR,ledger__info__pb2.DESCRIPTOR,])




_VALIDATORCHANGEEVENTWITHPROOF = _descriptor.Descriptor(
  name='ValidatorChangeEventWithProof',
  full_name='types.ValidatorChangeEventWithProof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_info_with_sigs', full_name='types.ValidatorChangeEventWithProof.ledger_info_with_sigs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_with_proof', full_name='types.ValidatorChangeEventWithProof.event_with_proof', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=211,
)

_VALIDATORCHANGEEVENTWITHPROOF.fields_by_name['ledger_info_with_sigs'].message_type = ledger__info__pb2._LEDGERINFOWITHSIGNATURES
_VALIDATORCHANGEEVENTWITHPROOF.fields_by_name['event_with_proof'].message_type = events__pb2._EVENTWITHPROOF
DESCRIPTOR.message_types_by_name['ValidatorChangeEventWithProof'] = _VALIDATORCHANGEEVENTWITHPROOF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ValidatorChangeEventWithProof = _reflection.GeneratedProtocolMessageType('ValidatorChangeEventWithProof', (_message.Message,), dict(
  DESCRIPTOR = _VALIDATORCHANGEEVENTWITHPROOF,
  __module__ = 'validator_change_pb2'
  # @@protoc_insertion_point(class_scope:types.ValidatorChangeEventWithProof)
  ))
_sym_db.RegisterMessage(ValidatorChangeEventWithProof)


# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import admission_control_pb2 as admission__control__pb2
from . import get_with_proof_pb2 as get__with__proof__pb2


class AdmissionControlStub(object):
  """-----------------------------------------------------------------------------
  ---------------- Service definition
  -----------------------------------------------------------------------------
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.SubmitTransaction = channel.unary_unary(
        '/admission_control.AdmissionControl/SubmitTransaction',
        request_serializer=admission__control__pb2.SubmitTransactionRequest.SerializeToString,
        response_deserializer=admission__control__pb2.SubmitTransactionResponse.FromString,
        )
    self.UpdateToLatestLedger = channel.unary_unary(
        '/admission_control.AdmissionControl/UpdateToLatestLedger',
        request_serializer=get__with__proof__pb2.UpdateToLatestLedgerRequest.SerializeToString,
        response_deserializer=get__with__proof__pb2.UpdateToLatestLedgerResponse.FromString,
        )


class AdmissionControlServicer(object):
  """-----------------------------------------------------------------------------
  ---------------- Service definition
  -----------------------------------------------------------------------------
  """

  def SubmitTransaction(self, request, context):
    """Public API to submit transaction to a validator.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateToLatestLedger(self, request, context):
    """This API is used to update the client to the latest ledger version and
    optionally also request 1..n other pieces of data.  This allows for batch
    queries.  All queries return proofs that a client should check to validate
    the data. Note that if a client only wishes to update to the latest
    LedgerInfo and receive the proof of this latest version, they can simply
    omit the requested_items (or pass an empty list)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AdmissionControlServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'SubmitTransaction': grpc.unary_unary_rpc_method_handler(
          servicer.SubmitTransaction,
          request_deserializer=admission__control__pb2.SubmitTransactionRequest.FromString,
          response_serializer=admission__control__pb2.SubmitTransactionResponse.SerializeToString,
      ),
      'UpdateToLatestLedger': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateToLatestLedger,
          request_deserializer=get__with__proof__pb2.UpdateToLatestLedgerRequest.FromString,
          response_serializer=get__with__proof__pb2.UpdateToLatestLedgerResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'admission_control.AdmissionControl', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: transaction_info.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='transaction_info.proto',
  package='types',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x16transaction_info.proto\x12\x05types\"v\n\x0fTransactionInfo\x12\x1f\n\x17signed_transaction_hash\x18\x01 \x01(\x0c\x12\x17\n\x0fstate_root_hash\x18\x02 \x01(\x0c\x12\x17\n\x0f\x65vent_root_hash\x18\x03 \x01(\x0c\x12\x10\n\x08gas_used\x18\x04 \x01(\x04\x62\x06proto3')
)




_TRANSACTIONINFO = _descriptor.Descriptor(
  name='TransactionInfo',
  full_name='types.TransactionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_transaction_hash', full_name='types.TransactionInfo.signed_transaction_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state_root_hash', full_name='types.TransactionInfo.state_root_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_root_hash', full_name='types.TransactionInfo.event_root_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gas_used', full_name='types.TransactionInfo.gas_used', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=151,
)

DESCRIPTOR.message_types_by_name['TransactionInfo'] = _TRANSACTIONINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TransactionInfo = _reflection.GeneratedProtocolMessageType('TransactionInfo', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTIONINFO,
  __module__ = 'transaction_info_pb2'
  # @@protoc_insertion_point(class_scope:types.TransactionInfo)
  ))
_sym_db.RegisterMessage(TransactionInfo)


# @@protoc_insertion_point(module_scope)



import requests
import time
from io import BytesIO
from grpc import insecure_channel
from sha3 import sha3_256

from pylibra.proto.admission_control_pb2 import SubmitTransactionRequest
from pylibra.proto.admission_control_pb2_grpc import AdmissionControlStub
from pylibra.proto.get_with_proof_pb2 import UpdateToLatestLedgerRequest
from pylibra.proto.transaction_pb2 import SignedTransaction, TransactionArgument
from pylibra.wallet.account_state import AccountState


LIBRA_TESTNET_HOST = "ac.testnet.libra.org:80"
FAUCET_HOST = "http://faucet.testnet.libra.org"
ACCOUNT_STATE_PATH = bytes.fromhex(
    "01217da6c6b3e19f1825cfb2676daecce3bf3de03cf26647c78df00b371b25cc97"
)


class LibraClient(object):
    def __init__(self, channel_uri=LIBRA_TESTNET_HOST, faucet=FAUCET_HOST):
        self.channel = insecure_channel(channel_uri)
        self.stub = AdmissionControlStub(self.channel)
        self.faucet = faucet

    def get_account_states(self, addresses):
        request = UpdateToLatestLedgerRequest()
        for address in addresses:
            requested_item = request.requested_items.add()
            requested_item.get_account_state_request.address = bytes.fromhex(address)
        response = self.stub.UpdateToLatestLedger(request)
        results = []
        for response in response.response_items:
            blob = response.get_account_state_response.account_state_with_proof.blob.blob
            buffer = BytesIO(blob)
            blob_len = int.from_bytes(buffer.read(4), byteorder="little")
            key_values = {}
            for idx in range(blob_len):
                key_len = int.from_bytes(buffer.read(4), byteorder="little")
                key = buffer.read(key_len)
                val_len = int.from_bytes(buffer.read(4), byteorder="little")
                val = buffer.read(val_len)
                key_values[key] = val
            if ACCOUNT_STATE_PATH in key_values:
                results.append(AccountState.from_bytes(key_values[ACCOUNT_STATE_PATH]))
        return results

    def get_account_state(self, address):
        return self.get_account_states([address])[0]

    def mint_with_faucet(self, receiver, value):
        response = requests.get(self.faucet, params={"address": receiver, "amount": value})
        if response.status_code != 200:
            raise Exception("Failed to send request to faucent service: {}".format(self.faucet))
        sequence_number = int(response.content)
        return sequence_number

    def send_transaction(
        self, sender, transaction, max_gas_amount=10000, gas_unit_price=0, expiration_time=None
    ):
        seq = self.get_account_state(sender.address).sequence_number
        if expiration_time is None:
            expiration_time = int(time.time()) + 10

        raw_tx = transaction.as_raw_transaction(
            sender.address, seq, max_gas_amount, gas_unit_price, expiration_time
        )
        raw_txn_bytes = raw_tx.SerializeToString()

        shazer = sha3_256()
        shazer.update(
            bytes.fromhex("46f174df6ca8de5ad29745f91584bb913e7df8dd162e3e921a5c1d8637c88d16")
        )
        shazer.update(raw_txn_bytes)

        request = SubmitTransactionRequest()
        signed_txn = request.signed_txn
        signed_txn.sender_public_key = bytes.fromhex(sender.public_key)
        signed_txn.raw_txn_bytes = raw_txn_bytes
        signed_txn.sender_signature = sender.sign(shazer.digest())[:64]
        return self.stub.SubmitTransaction(request)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mempool_status.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='mempool_status.proto',
  package='mempool',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x14mempool_status.proto\x12\x07mempool*\x96\x01\n\x1bMempoolAddTransactionStatus\x12\t\n\x05Valid\x10\x00\x12\x17\n\x13InsufficientBalance\x10\x01\x12\x14\n\x10InvalidSeqNumber\x10\x02\x12\x11\n\rMempoolIsFull\x10\x03\x12\x17\n\x13TooManyTransactions\x10\x04\x12\x11\n\rInvalidUpdate\x10\x05\x62\x06proto3')
)

_MEMPOOLADDTRANSACTIONSTATUS = _descriptor.EnumDescriptor(
  name='MempoolAddTransactionStatus',
  full_name='mempool.MempoolAddTransactionStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Valid', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InsufficientBalance', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidSeqNumber', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MempoolIsFull', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TooManyTransactions', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidUpdate', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=34,
  serialized_end=184,
)
_sym_db.RegisterEnumDescriptor(_MEMPOOLADDTRANSACTIONSTATUS)

MempoolAddTransactionStatus = enum_type_wrapper.EnumTypeWrapper(_MEMPOOLADDTRANSACTIONSTATUS)
Valid = 0
InsufficientBalance = 1
InvalidSeqNumber = 2
MempoolIsFull = 3
TooManyTransactions = 4
InvalidUpdate = 5


DESCRIPTOR.enum_types_by_name['MempoolAddTransactionStatus'] = _MEMPOOLADDTRANSACTIONSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proof.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import transaction_info_pb2 as transaction__info__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proof.proto',
  package='types',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0bproof.proto\x12\x05types\x1a\x16transaction_info.proto\"@\n\x10\x41\x63\x63umulatorProof\x12\x0e\n\x06\x62itmap\x18\x01 \x01(\x04\x12\x1c\n\x14non_default_siblings\x18\x02 \x03(\x0c\"O\n\x11SparseMerkleProof\x12\x0c\n\x04leaf\x18\x01 \x01(\x0c\x12\x0e\n\x06\x62itmap\x18\x02 \x01(\x0c\x12\x1c\n\x14non_default_siblings\x18\x03 \x03(\x0c\"\x92\x01\n\x16SignedTransactionProof\x12\x46\n%ledger_info_to_transaction_info_proof\x18\x01 \x01(\x0b\x32\x17.types.AccumulatorProof\x12\x30\n\x10transaction_info\x18\x02 \x01(\x0b\x32\x16.types.TransactionInfo\"\xd2\x01\n\x11\x41\x63\x63ountStateProof\x12\x46\n%ledger_info_to_transaction_info_proof\x18\x01 \x01(\x0b\x32\x17.types.AccumulatorProof\x12\x30\n\x10transaction_info\x18\x02 \x01(\x0b\x32\x16.types.TransactionInfo\x12\x43\n!transaction_info_to_account_proof\x18\x03 \x01(\x0b\x32\x18.types.SparseMerkleProof\"\xc8\x01\n\nEventProof\x12\x46\n%ledger_info_to_transaction_info_proof\x18\x01 \x01(\x0b\x32\x17.types.AccumulatorProof\x12\x30\n\x10transaction_info\x18\x02 \x01(\x0b\x32\x16.types.TransactionInfo\x12@\n\x1ftransaction_info_to_event_proof\x18\x03 \x01(\x0b\x32\x17.types.AccumulatorProofb\x06proto3')
  ,
  dependencies=[transaction__info__pb2.DESCRIPTOR,])




_ACCUMULATORPROOF = _descriptor.Descriptor(
  name='AccumulatorProof',
  full_name='types.AccumulatorProof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bitmap', full_name='types.AccumulatorProof.bitmap', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_default_siblings', full_name='types.AccumulatorProof.non_default_siblings', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=110,
)


_SPARSEMERKLEPROOF = _descriptor.Descriptor(
  name='SparseMerkleProof',
  full_name='types.SparseMerkleProof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='leaf', full_name='types.SparseMerkleProof.leaf', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bitmap', full_name='types.SparseMerkleProof.bitmap', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_default_siblings', full_name='types.SparseMerkleProof.non_default_siblings', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=191,
)


_SIGNEDTRANSACTIONPROOF = _descriptor.Descriptor(
  name='SignedTransactionProof',
  full_name='types.SignedTransactionProof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_info_to_transaction_info_proof', full_name='types.SignedTransactionProof.ledger_info_to_transaction_info_proof', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_info', full_name='types.SignedTransactionProof.transaction_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=340,
)


_ACCOUNTSTATEPROOF = _descriptor.Descriptor(
  name='AccountStateProof',
  full_name='types.AccountStateProof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_info_to_transaction_info_proof', full_name='types.AccountStateProof.ledger_info_to_transaction_info_proof', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_info', full_name='types.AccountStateProof.transaction_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_info_to_account_proof', full_name='types.AccountStateProof.transaction_info_to_account_proof', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=553,
)


_EVENTPROOF = _descriptor.Descriptor(
  name='EventProof',
  full_name='types.EventProof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_info_to_transaction_info_proof', full_name='types.EventProof.ledger_info_to_transaction_info_proof', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_info', full_name='types.EventProof.transaction_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_info_to_event_proof', full_name='types.EventProof.transaction_info_to_event_proof', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=756,
)

_SIGNEDTRANSACTIONPROOF.fields_by_name['ledger_info_to_transaction_info_proof'].message_type = _ACCUMULATORPROOF
_SIGNEDTRANSACTIONPROOF.fields_by_name['transaction_info'].message_type = transaction__info__pb2._TRANSACTIONINFO
_ACCOUNTSTATEPROOF.fields_by_name['ledger_info_to_transaction_info_proof'].message_type = _ACCUMULATORPROOF
_ACCOUNTSTATEPROOF.fields_by_name['transaction_info'].message_type = transaction__info__pb2._TRANSACTIONINFO
_ACCOUNTSTATEPROOF.fields_by_name['transaction_info_to_account_proof'].message_type = _SPARSEMERKLEPROOF
_EVENTPROOF.fields_by_name['ledger_info_to_transaction_info_proof'].message_type = _ACCUMULATORPROOF
_EVENTPROOF.fields_by_name['transaction_info'].message_type = transaction__info__pb2._TRANSACTIONINFO
_EVENTPROOF.fields_by_name['transaction_info_to_event_proof'].message_type = _ACCUMULATORPROOF
DESCRIPTOR.message_types_by_name['AccumulatorProof'] = _ACCUMULATORPROOF
DESCRIPTOR.message_types_by_name['SparseMerkleProof'] = _SPARSEMERKLEPROOF
DESCRIPTOR.message_types_by_name['SignedTransactionProof'] = _SIGNEDTRANSACTIONPROOF
DESCRIPTOR.message_types_by_name['AccountStateProof'] = _ACCOUNTSTATEPROOF
DESCRIPTOR.message_types_by_name['EventProof'] = _EVENTPROOF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccumulatorProof = _reflection.GeneratedProtocolMessageType('AccumulatorProof', (_message.Message,), dict(
  DESCRIPTOR = _ACCUMULATORPROOF,
  __module__ = 'proof_pb2'
  # @@protoc_insertion_point(class_scope:types.AccumulatorProof)
  ))
_sym_db.RegisterMessage(AccumulatorProof)

SparseMerkleProof = _reflection.GeneratedProtocolMessageType('SparseMerkleProof', (_message.Message,), dict(
  DESCRIPTOR = _SPARSEMERKLEPROOF,
  __module__ = 'proof_pb2'
  # @@protoc_insertion_point(class_scope:types.SparseMerkleProof)
  ))
_sym_db.RegisterMessage(SparseMerkleProof)

SignedTransactionProof = _reflection.GeneratedProtocolMessageType('SignedTransactionProof', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDTRANSACTIONPROOF,
  __module__ = 'proof_pb2'
  # @@protoc_insertion_point(class_scope:types.SignedTransactionProof)
  ))
_sym_db.RegisterMessage(SignedTransactionProof)

AccountStateProof = _reflection.GeneratedProtocolMessageType('AccountStateProof', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTSTATEPROOF,
  __module__ = 'proof_pb2'
  # @@protoc_insertion_point(class_scope:types.AccountStateProof)
  ))
_sym_db.RegisterMessage(AccountStateProof)

EventProof = _reflection.GeneratedProtocolMessageType('EventProof', (_message.Message,), dict(
  DESCRIPTOR = _EVENTPROOF,
  __module__ = 'proof_pb2'
  # @@protoc_insertion_point(class_scope:types.EventProof)
  ))
_sym_db.RegisterMessage(EventProof)


# @@protoc_insertion_point(module_scope)



import os
from setuptools import setup


REQUIREMENTS = [
    line.strip()
    for line in open(os.path.join(os.path.dirname(__file__), "requirements.txt")).readlines()
]


setup(
    name="pylibra",
    version="0.1.3",
    license="MIT",
    author="Band Protocol",
    author_email="opensource@bandprotocol.com",
    description="A Python client for Libra network",
    url="https://github.com/bandprotocol/pylibra",
    packages=["pylibra", "pylibra.wallet", "pylibra.proto", "pylibra.transaction"],
    keywords=["libra", "client", "cryptocurrency", "blockchain"],
    install_requires=REQUIREMENTS,
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: POSIX :: Linux",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: MacOS :: MacOS X",
    ],
)
